Discover Packages
github.com/FearLessSaad/SNFOK
tooling
logger
package
Version:
v0.0.0-...-9d183bc
Opens a new window with list of versions in this module.
Published: May 28, 2025
License: GPL-3.0
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
const (
INFO = "INFO"
ERROR = "ERROR"
DEBUG = "DEBUG"
WARN = "WARN"
ERROR_MESSAGE = "err_msg"
)
Log writes a log message at the specified level with optional fields.
If level is empty, it defaults to "info".
Logs are written to both a file and stdout.
type Field struct {
Key string
Value interface{}
}
Field represents a key-value pair for structured logging.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.